metadata(version="3.3.4")

require("os")

module("getopt.py")
